@@ -168,6 +168,14 @@ class Image(_ecvl.Image):
             self, dims, elemtype, channels, colortype, spacings, dev
         )
 
+    def copy(self):
+        """\
+        Create a deep copy of this image.
+
+        :return: a copy of this image
+        """
+        return _ecvl.Image(self)
+
     def IsEmpty(self):
         """\
         Whether the image contains data or not.
@@ -312,6 +320,20 @@ def CopyImage(src, dst, new_type=None):
     return _ecvl.CopyImage(src, dst, new_type)
 
 
+def ShallowCopyImage(src, dst):
+    """\
+    Shallow copy of ``src`` to ``dst`` (``dst`` will point to the same data).
+
+    ``src`` and ``dst`` cannot be the same image. Even though ``dst`` will
+    point to the same data as ``src``, the latter will be the data owner.
+
+    :param src: source image
+    :param dst: destination image
+    :return: None
+    """
+    return _ecvl.ShallowCopyImage(src, dst)
+
+
 def RearrangeChannels(src, dst, channels, new_type=None):
     """\
     Change image dimensions order.
@@ -611,6 +633,23 @@ def Threshold(src, dst, thresh, maxval, thresh_type=ThresholdingType.BINARY):
     return _ecvl.Threshold(src, dst, thresh, maxval, thresh_type)
 
 
+def MultiThreshold(src, dst, thresholds, minval=0, maxval=255):
+    """\
+    Apply multiple thresholds to an image.
+
+    The resulting image is quantized based on the provided ``thresholds``
+    values. Output values will range uniformly from ``minval`` to ``maxval``.
+
+    :param src: source image
+    :param dst: destination image
+    :param thresh: threshold values
+    :param maxval: minimum value in the output image
+    :param maxval: maximum value in the output image
+    :return: None
+    """
+    return _ecvl.MultiThreshold(src, dst, thresholds, minval, maxval)
+
+
 def OtsuThreshold(src):
     """\
     Calculate the Otsu thresholding value.
@@ -623,6 +662,19 @@ def OtsuThreshold(src):
     return _ecvl.OtsuThreshold(src)
 
 
+def OtsuMultiThreshold(src, n_thresholds=2):
+    """\
+    Calculate the Otsu thresholding values.
+
+    The image must be ColorType.GRAY. The number of thresholds to be found is
+    defined by the n_thresholds parameter (default is 2).
+
+    :param src: source image
+    :return: Otsu threshold values (list of integers)
+    """
+    return _ecvl.OtsuMultiThreshold(src, n_thresholds)
+
+
 def Filter2D(src, dst, ker, type=DataType.none):
     """\
     Convolve an image with a kernel.
@@ -1041,6 +1093,85 @@ def SliceTimingCorrection(src, dst, odd=False, down=False):
     return _ecvl.SliceTimingCorrection(src, dst, odd, down)
 
 
+def Moments(src, dst, order=3, type_=DataType.float64):
+    """\
+    Calculate raw image moments of the source image up to the specified order.
+
+    Moments are stored in the output image in the same order as for source
+    channels. The output image will be on the same device as the source image.
+
+    :param src: input image. It must be a grayscale (ColorType.GRAY) or a
+      data (ColorType.none) image.
+    :param dst: output image (ColorType.none) containing the computed raw
+      image moments. The size of the Image will be (order + 1, order + 1)
+    :param order: moments order
+    :param type_: data type for the output image
+
+    """
+    return _ecvl.Moments(src, dst, order, type_)
+
+
+def CentralMoments(src, moments, center, order=3, type_=DataType.float64):
+    """\
+    Calculate central moments of the source image up to the specified order.
+
+    :param src: input image. It must be a grayscale (ColorType.GRAY) or a
+      data (ColorType.none) image.
+    :param moments: output data (ColorType.none) image containing the computed
+      moments. The size of the Image will be (order + 1, order + 1)
+    :param center: center coordinates (list of floats) ``len(center)`` and
+      ``src.dims_`` must match. The source axes order must be the same used to
+      specify the center coordinates.
+    :param order: moments order
+    :param type_: data type for the output image
+    """
+    return _ecvl.CentralMoments(src, moments, center, order, type_)
+
+
+def DrawEllipse(src, center, axes, angle, color, thickness=1):
+    """\
+    Draw an ellipse over the specified Image.
+
+    :param src: input (and output) image.
+    :param center: center of the ellipse
+    :param axes: ellipse axes half size
+    :param angle: rotation angle of the ellipse
+    :param color: ellipse color, e.g., ``[255]``, ``[5, 5, 5]`` (RGB)
+    :param thickness: ellipse border thickness. If negative all the pixels of
+      the ellipse will be filled with the specified color value.
+    """
+    return _ecvl.DrawEllipse(src, center, axes, angle, color, thickness)
+
+
+def DropColorChannel(src):
+    """\
+    Remove color channel from the input image.
+
+    Remove the color channel ("c") from the specified input image, modifying
+    all other attributes accordingly. This function can only be applied to
+    images with ``ColorType.GRAY``, i.e., having the color channel dimension
+    equal to 1.
+
+    :param src: input image.
+    """
+    return _ecvl.DropColorChannel(src)
+
+
+def Normalize(src, dst, mean, std):
+    """\
+    Normalize the input image with mean and standard deviation.
+
+    For each pixel, subtract mean and divide by std. Useful to normalize a
+    dataset, getting the data within a range.
+
+    :param src: input image.
+    :param dst: output image.
+    :param mean: mean to use for normalization.
+    :param std: standard deviation to use for normalization.
+    """
+    return _ecvl.Normalize(src, dst, mean, std)
+
+
 # == dataset_parser ==
 
 class SplitType(_ecvl.SplitType):
@@ -1678,6 +1809,28 @@ class AugSaltAndPepper(_ecvl.AugSaltAndPepper):
         _ecvl.AugSaltAndPepper.__init__(self, p, per_channel)
 
 
+class AugNormalize(_ecvl.AugNormalize):
+    """\
+    Augmentation wrapper for Normalize.
+    """
+
+    @staticmethod
+    def fromtext(txt):
+        r"""\
+        Create an AugNormalize from a text description, e.g.::
+
+            a = AugNormalize('mean=20 std=5.5')
+        """
+        return _ecvl.AugNormalize(txt)
+
+    def __init__(self, mean, std):
+        """\
+        :param mean: mean to use for normalization
+        :param std: standard deviation to use for normalization
+        """
+        _ecvl.AugNormalize.__init__(self, mean, std)
+
+
 # == support_imgcodecs ==
 
 class ImReadMode(_ecvl.ImReadMode):
@@ -1824,9 +1977,9 @@ class DLDataset(_ecvl.DLDataset):
 
 # FIXME: the version with offset does not make sense, since we are returning
 # the output tensor
-def ImageToTensor(img, offset=None):
+def ImageToTensor(img, t=None, offset=None):
     """\
-    Insert an ECVL Image into an EDDL Tensor.
+    Convert an ECVL Image to an EDDL Tensor.
 
     The input image must have 3 dimensions "xy[czo]" (in any order). The output
     tensor's dimensions will be C x H x W, where:
@@ -1835,13 +1988,24 @@ def ImageToTensor(img, offset=None):
     * H = height
     * W = width
 
+    If ``t`` and ``offset`` are None, a new tensor is created with the above
+    shape.
+
+    If ``t`` and ``offset`` are not None, the data are inserted into the
+    existing ``t`` tensor at the specified offset. This allows to insert more
+    than one image into a tensor, specifying how many images are already
+    stored in it.
+
     :param img: input image
+    :param t: output tensor
     :param offset: how many images are already stored in the tensor
     :return: output tensor
     """
-    if offset is None:
+    if t is None and offset is None:
         return _ecvl.ImageToTensor(img)
-    return _ecvl.ImageToTensor(img, offset)
+    else:
+        _ecvl.ImageToTensor(img, t, offset)
+        return t
 
 
 def TensorToImage(t):
