@@ -46,6 +46,31 @@ def test_empty(ecvl):
     assert img.IsEmpty()
 
 
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_copy(ecvl):
+    dims, dtype = [2, 4, 3], ecvl.DataType.int8
+    ch, ctype = "xyc", ecvl.ColorType.RGB
+    x = ecvl.Image(dims, dtype, ch, ctype)
+    a = np.array(x, copy=False)
+    a.fill(3)
+    y = x.copy()
+    assert y.dims_ == dims
+    assert y.elemtype_ == dtype
+    assert y.channels_ == ch
+    assert y.colortype_ == ctype
+    b = np.array(y, copy=False)
+    assert (b == 3).all()
+    # ecvl_core can also use copy constructor binding
+    if ecvl is ecvl_core:
+        y = ecvl.Image(x)
+        assert y.dims_ == dims
+        assert y.elemtype_ == dtype
+        assert y.channels_ == ch
+        assert y.colortype_ == ctype
+        b = np.array(y, copy=False)
+        assert (b == 3).all()
+
+
 @pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
 def test_five_dims(ecvl):
     dims = [1, 2, 3, 4, 5]
@@ -284,3 +309,24 @@ def test_copy_image(ecvl):
     assert y.colortype_ == ctype
     b = np.array(y, copy=False)
     assert (b == 3).all()
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_shallow_copy_image(ecvl):
+    dims, dtype = [2, 4, 3], ecvl.DataType.int8
+    ch, ctype = "xyc", ecvl.ColorType.RGB
+    x = ecvl.Image(dims, dtype, ch, ctype)
+    a = np.array(x, copy=False)
+    a.fill(3)
+    y = _empty_img(ecvl)
+    ecvl.ShallowCopyImage(x, y)
+    assert y.dims_ == dims
+    assert y.elemtype_ == dtype
+    assert y.channels_ == ch
+    assert y.colortype_ == ctype
+    b = np.array(y, copy=False)
+    assert (b == 3).all()
+    b.fill(4)
+    assert (a == 4).all()
+    assert x.IsOwner()
+    assert not y.IsOwner()
